<?php
// setup the various stuffs
function slides_setup() {
	add_editor_style();
	add_theme_support( 'post-formats', array('aside', 'audio', 'chat', 'gallery', 'image', 'link', 'quote', 'status', 'video') );
	add_theme_support( 'custom-background', array('default-color' => '000000') );
	
	// don't allow empty logos
	if (! get_theme_mod('square_logo', false) ) {
		remove_theme_mod('square_logo');
	}

	if (! get_theme_mod('front_logo', false) ) {
		remove_theme_mod('front_logo');
	}
}
add_action( 'after_setup_theme', 'slides_setup' );

// add the stylesheets
function slides_scripts_styles() {
	global $wp_styles;
	wp_enqueue_style( 'slides-style', get_stylesheet_uri() );
	wp_enqueue_style( 'slides-phone-style', get_template_directory_uri().'/css/phone.css', array(), false, 'only screen and (max-device-width: 480px)' );  
}
add_action( 'wp_enqueue_scripts', 'slides_scripts_styles' );

// force blog to show all posts/slides
function slides_force_all_posts( $query ) {
    if ( $query->is_home() && $query->is_main_query() ) {
    	$query->set( 'post_type', 'page' );
    	$query->set( 'post_status', 'publish' );
    	$query->set( 'orderby', 'menu_order' );
    	$query->set( 'order', 'ASC' );
        $query->set( 'posts_per_page', '-1' );
    }
}
add_action( 'pre_get_posts', 'slides_force_all_posts' );

// show the page ordering column
function slides_page_order_column($columns) {
	$columns['menu_order'] = 'Order';
	return $columns;
}
add_filter('manage_pages_columns', 'slides_page_order_column');

// show the page ordering column content
function slides_page_order_column_content( $column, $post_id ) {
	global $post;
	switch ( $column ) {
	case 'menu_order' :
		echo $post->menu_order;
	}
}
add_action( 'manage_pages_custom_column' , 'slides_page_order_column_content', 10, 2 );

// special slide classes
function slides_class() {
	$tags=array();
	if ( has_term( 'thank-you-slide', 'slide_options' ) ) $tags[] = 'thank-you-slide';
	if ( has_term( 'segue', 'slide_options' ) ) $tags[] = 'segue';
	if ( has_term( 'nobackground', 'slide_options' ) ) $tags[] = 'nobackground';
	if ( has_term( 'dark', 'slide_options' ) ) $tags[] = 'dark';
	
	// thumbnails are the backgrounds, automatically use fill and nobackground classes on them
	if ( has_post_thumbnail() ) {
		$tags[] = 'nobackground';
		$tags[] = 'fill';
	}
	echo 'class="' . join( ' ', array_unique($tags) ) . '"';
}

// post class handling
add_filter('post_class','slides_post_class');
function slides_post_class( $classes ) {
	if (has_term('smaller', 'slide_options')) $classes[] = 'smaller';
	return $classes;
}


// turn off posts and comments menus
add_action( 'admin_menu', 'slides_remove_posts_comments');  
function slides_remove_posts_comments() {
	remove_menu_page('edit.php');
	remove_menu_page('edit-comments.php');
}

// disable comments completely
add_filter( 'comments_open', '__return_false' );
add_filter( 'pings_open', '__return_false' );

// hide admin bar on front
if (!is_admin()) 
	add_filter('show_admin_bar','__return_false');

// some basic setup
add_action( 'init', 'register_taxonomy_slide_options' );
function register_taxonomy_slide_options() {

	$labels = array( 
		'name' => _x( 'Slide options', 'taxonomy name' ),
		'singular_name' => _x( 'Slide option', 'taxonomy singular name' ),
		'menu_name' => _x( 'Slide options', 'taxonomy menu name' ),
	);

	$args = array( 
		'labels' => $labels,
		'public' => true,
		'show_in_nav_menus' => false,
		'show_ui' => true,
		'show_tagcloud' => false,
		'show_admin_column' => true,
		'hierarchical' => false,
		'rewrite' => false,
		'query_var' => false
	);

	register_taxonomy( 'slide_options', array('page'), $args );
	
	add_theme_support( 'post-thumbnails' );
	set_post_thumbnail_size( 604, 270, true );

	add_post_type_support( 'page', array('excerpt') );
}

// get rid of the default meta box for the new taxonomy
add_action( 'admin_menu', 'slides_remove_meta_box');  
function slides_remove_meta_box(){  
	remove_meta_box('tagsdiv-slide_options', 'page', 'normal');
}  

// Add new taxonomy meta box  
add_action( 'add_meta_boxes', 'slides_add_meta_box');  
function slides_add_meta_box() {  
	add_meta_box( 'slide_options', 'Slide Options', 'slide_options_metabox','page' ,'side','core');  
} 

// add the options menu
add_action( 'admin_menu', 'slides_add_theme_page' );
function slides_add_theme_page() {
	//add_theme_page( 'Customize', 'Customize', 'edit_theme_options', 'customize.php' );
}

add_action('customize_register', 'slides_customize');
function slides_customize($wp_customize) {

	// this makes no sense for this theme
	$wp_customize->remove_section( 'static_front_page' );

	$wp_customize->add_section( 'slides_plugin_check', array(
		'title'          => __('Supported Plugins', 'slides'),
		'priority'       => 35,
	) );

	$wp_customize->add_setting( 'fake_setting', array(
		'default'        => 'default_value',
	) );

	$wp_customize->add_control( new Slides_Customize_PluginCheck_Control( $wp_customize, 'fake_setting', array(
		'label'   => 'Plugins',
		'section' => 'slides_plugin_check',
		'settings'   => 'fake_setting',
	) ) );

	$wp_customize->add_section( 'slides_logo_info', array(
		'title'          => __('Logos', 'slides'),
		'priority'       => 37,
	) );

	$wp_customize->add_setting( 'front_logo', array(
		'default'        => get_template_directory_uri() . '/images/wordpress-logo-hoz-rgb.png',
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'front_logo', array(
		'label'   => 'Front Logo',
		'section' => 'slides_logo_info',
		'settings'   => 'front_logo',
	) ) );
    
	$wp_customize->add_setting( 'square_logo', array(
		'default'        => get_template_directory_uri() . '/images/wordpress-logo-notext-rgb.png',
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'square_logo', array(
		'label'   => 'Square Logo (on slide 2)',
		'section' => 'slides_logo_info',
		'settings'   => 'square_logo',
	) ) );

	$wp_customize->add_section( 'slides_event_info', array(
		'title'          => __('Event Information', 'slides'),
		'priority'       => 38,
	) );

	$wp_customize->add_setting( 'event_name', array(
		'default'        => '',
	) );

	$wp_customize->add_control( 'event_name', array(
		'label'   => 'Name',
		'section' => 'slides_event_info',
		'type'    => 'text',
		'priority'=> 1,
	) );

	$wp_customize->add_setting( 'event_date', array(
		'default'        => '',
	) );

	$wp_customize->add_control( 'event_date', array(
		'label'   => 'Date',
		'section' => 'slides_event_info',
		'type'    => 'text',
		'priority'=> 2,
	) );

	$wp_customize->add_section( 'slides_author_info', array(
		'title'          => __('Author Information', 'slides'),
		'priority'       => 39,
	) );

	$wp_customize->add_setting( 'author_name', array(
		'default'        => '',
	) );

	$wp_customize->add_control( 'author_name', array(
		'label'   => 'Name',
		'section' => 'slides_author_info',
		'type'    => 'text',
		'priority'=> 1,
	) );

	$wp_customize->add_setting( 'author_company', array(
		'default'        => '',
	) );

	$wp_customize->add_control( 'author_company', array(
		'label'   => 'Company',
		'section' => 'slides_author_info',
		'type'    => 'text',
		'priority'=> 2,
	) );

	$wp_customize->add_setting( 'author_gplus', array(
		'default'        => '',
	) );

	$wp_customize->add_control( 'author_gplus', array(
		'label'   => 'Google+',
		'section' => 'slides_author_info',
		'type'    => 'text',
		'priority'=> 3,
	) );
	
	$wp_customize->add_setting( 'author_twitter', array(
		'default'        => '',
	) );

	$wp_customize->add_control( 'author_twitter', array(
		'label'   => 'Twitter',
		'section' => 'slides_author_info',
		'type'    => 'text',
		'priority'=> 4,
	) );

	$wp_customize->add_setting( 'author_www', array(
		'default'	=> '',
	) );

	$wp_customize->add_control( 'author_www', array(
		'label'   => 'URL',
		'section' => 'slides_author_info',
		'type'    => 'text',
		'priority'=> 5,
	) );

	$wp_customize->add_setting( 'author_github', array(
		'default'        => '',
	) );

	$wp_customize->add_control( 'author_github', array(
		'label'   => 'GitHub',
		'section' => 'slides_author_info',
		'type'    => 'text',
		'priority'=> 6,
	) );
}

if (class_exists('WP_Customize_Control')) {
	class Slides_Customize_PluginCheck_Control extends WP_Customize_Control {
		public $type = 'none';

		public function render_content() {
			if ( ! class_exists( 'Simple_Page_Ordering' ) ) {
				?>
<p>The Slides theme has special functionality to support use of the <a href="http://wordpress.org/plugins/simple-page-ordering/">Simple Page Ordering</a> plugin. You can install this plugin to get support for drag/drop of your posts/slides and thus allow reordering of them to be done easily.</p>
				<?php
				$plugins = get_plugins();
				$uris = wp_list_pluck($plugins, 'PluginURI');

				if ( ( $plugin_file = array_search('http://10up.com/plugins/simple-page-ordering-wordpress/', $uris) ) !== false ) {
					// plugin installed, but not active
					?>
<p>Plugin already installed, but not activated. <a href="<?php echo wp_nonce_url(self_admin_url('plugins.php?action=activate&plugin='.$plugin_file), 'activate-plugin_'.$plugin_file); ?>">Click here to activate the Simple Page Ordering plugin</a></p>
				<?php
				} else {
					// plugin not installed
					require_once ABSPATH . 'wp-admin/includes/plugin-install.php';
					$info = plugins_api('plugin_information', array('slug' => 'simple-page-ordering' ));
					if ( is_wp_error( $info ) ) {
						// TODO
					}
				?>
<p>Plugin not installed. <a href="<?php echo wp_nonce_url(self_admin_url('update.php?action=install-plugin&plugin=simple-page-ordering'), 'install-plugin_simple-page-ordering');	?>">Click here to install the Simple Page Ordering plugin</a></p>
				<?php
				}
			} else {
				echo '<p>'.__('Simple Page Ordering plugin installed and active!','slides') .'</p>';
			}
		}
	}
}

//Callback to set up the metabox
function slide_options_metabox( $post ) {
	//Get taxonomy and terms
	$taxonomy = 'slide_options';

	//Set up the taxonomy object and get terms
	$tax = get_taxonomy($taxonomy);

	$tagterms = array('nobackground', 'segue', 'thank-you-slide', 'smaller', 'dark');

	$terms = get_terms($taxonomy,array('hide_empty' => 0));

	//Name of the form
	$name = 'tax_input[' . $taxonomy . ']';

	//Get current and popular terms
	$postterms = get_the_terms( $post->ID,$taxonomy );
	if ( !empty($postterms) ) 
		$activeterms = wp_list_pluck($postterms, 'slug');
	else 
		$activeterms = array();
	?>

	<div id="taxonomy-<?php echo $taxonomy; ?>" class="categorydiv">

	<!-- Display taxonomy terms -->
	<div id="<?php echo $taxonomy; ?>-all" class="tabs-panel">
		<ul id="<?php echo $taxonomy; ?>checklist" class="list:<?php echo $taxonomy?> categorychecklist form-no-clear">
		<?php   
		foreach($tagterms as $term){
			$id = $taxonomy.'-'.$term;
			if ( in_array( $term, $activeterms ) ) 
				$checked = checked(1,1,false);
			else $checked = '';
			echo "<li id='$id'><label class='selectit'>";
			echo "<input type='checkbox' id='in-$id' name='{$name}[]' $checked value='$term' />$term<br />";
			echo "</label></li>";
		}
		?>
		</ul>
	</div>

	</div>
	<?php
}

// config for the title page
function slides_config() {
	$slide_config = array();
	$slide_config['settings'] = array(
		'title' => get_bloginfo( 'name', 'display' ),
		'subtitle' => get_bloginfo( 'description' ),
		'eventInfo' => array(
			'title' => get_theme_mod('event_name'),
			'date' => get_theme_mod('event_date'),
			),
		'useBuilds' => true,
		'usePrettify' => true,
		'enableSlideAreas' => true,
		'enableTouch' => true,
		'favIcon' => get_stylesheet_uri().'/images/wpmini-blue.png',
		'fonts' => array(
			'Open Sans:regular,semibold,italic,italicsemibold',
			'Source Code Pro'
			),
		);

	$presenters = array();
	$author = array();
	$info = get_theme_mods();
	foreach ($info as $key=>$value) {
		if ( strpos($key, 'author') !== false ) {
			$key = str_replace('author_','',$key);
			$author[$key] = $value;
		}
	}
	$presenters[] = $author;
	$slide_config['presenters'] = $presenters;
	?>
<script type="text/javascript">
var SLIDE_CONFIG = <?php echo json_encode($slide_config); ?>
</script>
<?php
}
add_action( 'wp_print_scripts', 'slides_config', 9);


// add more buttons to the html editor
function slides_add_quicktags() {
?>
    <script type="text/javascript">
    QTags.addButton( 'eg_pre', 'PHP Code', '<pre class="prettyprint" data-lang="php">\n', '</pre>', '', 'PHP Code', 300 );
    </script>
<?php
}
add_action( 'admin_print_footer_scripts', 'slides_add_quicktags' );
